@@ -83,7 +83,7 @@ void backgrounds::on_clockset_clicked()
     QStringList args;
     args << "changeimagepushed" << "clock.png";
     QProcess *jau = new QProcess(this);
-    jau->start("/sbin/customizer", args);
+    jau->start("/sbin/launchcustomizer", args);
     system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Image saved!'");
 }
 
@@ -97,7 +97,7 @@ void backgrounds::on_appmanagerset_clicked()
     QStringList args;
     args << "changeimagepushed" << "appmanager.png";
     QProcess *jau = new QProcess(this);
-    jau->start("/sbin/customizer", args);
+    jau->start("/sbin/launchcustomizer", args);
     system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Image saved!'");
 }
 
@@ -111,7 +111,7 @@ void backgrounds::on_mplayerset_clicked()
     QStringList args;
     args << "changeimagepushed" << "mplayer.png";
     QProcess *jau = new QProcess(this);
-    jau->start("/sbin/customizer", args);
+    jau->start("/sbin/launchcustomizer", args);
     system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Image saved!'");
 }
 
@@ -125,6 +125,6 @@ void backgrounds::on_lockset_2_clicked()
     QStringList args;
     args << "changeimagepushed" << "lock.png";
     QProcess *jau = new QProcess(this);
-    jau->start("/sbin/customizer", args);
+    jau->start("/sbin/launchcustomizer", args);
     system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Image saved!'");
 }
