@@ -541,7 +541,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: D-Iivil - Licence: Freeware & open source");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-21<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Donate some beer money to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-22<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
@@ -683,10 +683,18 @@ void MainWindow::on_pushButton_4_clicked()
 
 void MainWindow::loadclicked()
 {
-    if (!ManWin->ui->presetslist->currentIndex() == 0) {
-    loadpr = "/opt/theme-customizer/presets/" + ManWin->ui->presetslist->currentText();
+    if (ManWin->ui->presetslist->currentIndex() == 1) {
+        loadpr = "/etc/hildon/theme/colors.config";
+    } else if (ManWin->ui->presetslist->currentIndex() == 2) {
+        QString colorfile = QFileInfo("/etc/hildon/theme/colors.config").canonicalFilePath();
+        QString originalcolorfile = "/opt/theme-customizer/backups/" + colorfile;
+        if (QFile(originalcolorfile).exists()) {
+            loadpr = originalcolorfile;
+        } else {
+            loadpr = "/etc/hildon/theme/colors.config";
+        }
     } else {
-    loadpr = "/etc/hildon/theme/colors.config";
+    loadpr = "/opt/theme-customizer/presets/" + ManWin->ui->presetslist->currentText();
     }
     oldfonts(loadpr);
     ManWin->hide();
