@@ -15,6 +15,11 @@
 #include "backgrounds.h"
 #include <QFileInfo>
 #include <QPainter>
+#include "savepreset.h"
+#include "ui_savepreset.h"
+#include "managepresets.h"
+#include "ui_managepresets.h"
+#include <QtMaemo5/QMaemo5InformationBox>
 
 namespace Ui {
     class MainWindow;
@@ -26,6 +31,8 @@ class MainWindow : public QMainWindow
 
 public:
     explicit MainWindow(QWidget *parent = 0);
+    void oldfonts(QString preset);
+    QString loadpr;
     ~MainWindow();
 
 private:
@@ -35,7 +42,6 @@ private:
     QProgressDialog progress3;
     QColorDialog colors;
     void readdirs();
-    void oldfonts();
     void readgtkrc();
     QStringList fonts;
     QHash<QString, QString> variables;
@@ -52,10 +58,15 @@ private:
     QString f7;
     QString f8;
     backgrounds* newWin;
-    bool openManWin;
-    bool openNewWin;
+    savepreset* SaveWin;
+    managepresets* ManWin;
 
 private slots:
+    void loadclicked();
+    void delclicked();
+    void on_pushButton_4_clicked();
+    void savedone();
+    void on_pushButton_3_clicked();
     void on_actionChange_backgrounds_triggered();
     void on_horizontalSlider_4_valueChanged(int value);
     void on_Opacity_editingFinished();
