@@ -24,10 +24,14 @@ void managepresets::readpresets()
 void managepresets::on_presetslist_currentIndexChanged(int index)
 {
 
-        if (!ui->presetslist->currentIndex() == 0) {
+        if (ui->presetslist->currentIndex() > 2) {
         ui->delbutton->setEnabled(true);
         } else {
         ui->delbutton->setDisabled(true);
         }
 
+        if (!ui->presetslist->currentIndex() == 0) {
+            ui->loadbutton->setEnabled(true);
+        }
+
 }
