@@ -363,5 +363,10 @@
         <source>Manage color presets</source>
         <translation>Gestion des présélections de couleurs</translation>
     </message>
+    <message>
+        <location filename="managepresets.ui" line="0"/>
+        <source>Original colors of current theme</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
